Package: NHSRdatasets
Type: Package
Title: NHS and Healthcare-Related Data for Education and Training
Date: 2021-03-09
Version: 0.3.0
Authors@R: c(
          person("Gary", "Hutson", , "g.hutson@nhs.net", "aut"),
          person("Tom", "Jemmett", ,"thomas.jemmett@nhs.net", "aut", comment = c(ORCID="0000-0002-6943-2990")),
          person("Chris", "Mainey", ,"c.mainey@nhs.net", c("aut", "cre"), comment = c(ORCID ="0000-0002-3018-6171")),
          person("Zoë", "Turner", , "zoe.turner@nhs.net", "aut" ),
          person("NHS-R community", role = "cph")
          )
Maintainer: Chris Mainey <c.mainey@nhs.net>
Description: Free United Kingdom National Health Service (NHS) and other healthcare, or population health-related data for education and training purposes. This package contains synthetic data based on real healthcare datasets, or cuts of open-licenced official data.  This package exists to support skills development in the NHS-R community: <https://nhsrcommunity.com/>.
License: CC0
Language: en-GB
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
Depends: R (>= 3.5.0)
BugReports: https://github.com/nhs-r-community/NHSRdatasets/issues
Imports: tibble
Suggests: dplyr, caret, e1071, readr, lattice, magrittr, varhandle,
        rsample, ggplot2, lme4, MASS, ModelMetrics, lmtest, rmarkdown,
        scales, ggrepel, lubridate, tidyr, forcats, knitr, janitor,
        stringi, synthpop
VignetteBuilder: knitr
URL: https://github.com/nhs-r-community/NHSRdatasets,
        https://nhs-r-community.github.io/NHSRdatasets/
NeedsCompilation: no
Packaged: 2021-03-11 08:09:48 UTC; Christopher
Author: Gary Hutson [aut],
  Tom Jemmett [aut] (<https://orcid.org/0000-0002-6943-2990>),
  Chris Mainey [aut, cre] (<https://orcid.org/0000-0002-3018-6171>),
  Zoë Turner [aut],
  NHS-R community [cph]
Repository: CRAN
Date/Publication: 2021-03-14 00:00:06 UTC
Built: R 4.6.0; ; 2026-04-26 09:06:07 UTC; unix
